cumulusci.core.config package
=============================

Submodules
----------


.. automodule:: cumulusci.core.config.BaseConfig
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.core.config.BaseGlobalConfig
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.core.config.BaseTaskFlowConfig
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.core.config.OrgConfig
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.core.config.ScratchOrgConfig
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.core.config.project_config
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.core.config
   :members:
   :undoc-members:
   :show-inheritance:
